@@ -12,7 +12,6 @@ import org.gcube.portal.databook.shared.Notification;
 import org.gcube.portal.databook.shared.NotificationChannelType;
 import org.gcube.portal.databook.shared.NotificationType;
 import org.gcube.portal.databook.shared.RunningJob;
-import org.gcube.portal.databook.shared.ex.NotificationChannelTypeNotFoundException;
 import org.gcube.portlets.user.homelibrary.home.exceptions.InternalErrorException;
 import org.gcube.portlets.user.homelibrary.home.workspace.WorkspaceFolder;
 import org.gcube.portlets.user.homelibrary.home.workspace.WorkspaceItem;
@@ -37,6 +36,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 */
 	public ApplicationNotificationsManager(ASLSession session) {
 		super(session);
+		_log.warn("Asked for Simple Notification (without redirect to creator)");
 	}
 	/**
 	 * Use this constructor if you do need notifications to point back to your applications, 
@@ -106,7 +106,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				userIdToNotify, //user no notify
 				sharedFolder.getId(),  //the 
 				new Date(),
-				"?itemid="+sharedFolder.getId(), 
+				getApplicationUrl()+"?itemid="+sharedFolder.getId(), 
 				"shared the workspace folder "+ sharedFolder.getName() +" with you",
 				false, 
 				aslSession.getUsername(),
@@ -127,7 +127,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				userIdToNotify, //user no notify
 				renamedFolderId,  //the 
 				new Date(),
-				"?itemid="+renamedFolderId, 
+				getApplicationUrl()+"?itemid="+renamedFolderId, 
 				"renamed your shared folder "+ previousName +" as " + newName,
 				false, 
 				aslSession.getUsername(),
@@ -152,7 +152,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				userIdToNotify, //user no notify
 				sharedFolder.getId(),  //the 
 				new Date(),
-				"?itemid="+sharedFolder.getId(),
+				getApplicationUrl()+"?itemid="+sharedFolder.getId(),
 				"added "+ user.getFullname() +" to your workspace shared folder "+ sharedFolder.getName(),
 				false, 
 				aslSession.getUsername(),
@@ -183,7 +183,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 					userIdToNotify, //user no notify
 					sharedFolder.getId(),  //the 
 					new Date(),
-					"?itemid="+sharedFolder.getId(),
+					getApplicationUrl()+"?itemid="+sharedFolder.getId(),
 					"added "+ addedUsersFullNames +" to your workspace shared folder "+ sharedFolder.getName(),
 					false, 
 					aslSession.getUsername(),
@@ -206,7 +206,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				userIdToNotify, //user no notify
 				sharedFolder.getId(),  //the 
 				new Date(),
-				"?itemid="+sharedFolder.getId(), 
+				getApplicationUrl()+"?itemid="+sharedFolder.getId(), 
 				"unshared his shared folder "+ sharedFolder.getName() + " from your workspace",
 				false, 
 				aslSession.getUsername(),
@@ -227,7 +227,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				userIdToNotify, //user no notify
 				item.getId(),  //the 
 				new Date(),
-				"?itemid="+item.getParent().getId(), 
+				getApplicationUrl()+"?itemid="+item.getParent().getId(), 
 				"added "+ item.getName() +" to your workspace shared folder "+ sharedFolder.getName(),
 				false, 
 				aslSession.getUsername(),
@@ -241,15 +241,36 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 	 * @throws InternalErrorException 
 	 */
 	@Override
-	public boolean notifyRemovedItem(String userIdToNotify,	WorkspaceItem item, WorkspaceFolder sharedFolder) throws InternalErrorException {
+	public boolean notifyMovedItem(String userIdToNotify,	WorkspaceItem item, WorkspaceFolder sharedFolder) throws InternalErrorException {
 		Notification not = new Notification(
 				UUID.randomUUID().toString(), 
 				NotificationType.WP_ITEM_DELETE, 
 				userIdToNotify, //user no notify
 				item.getId(),  //the 
 				new Date(),
-				"?itemid="+item.getParent().getId(), 
-				"removed "+ item.getName() +" from your workspace shared folder "+ sharedFolder.getName(),
+				getApplicationUrl()+"?itemid="+sharedFolder.getId(), 
+				"removed item "+ item.getName() +" from your workspace shared folder "+ sharedFolder.getName(),
+				false, 
+				aslSession.getUsername(),
+				aslSession.getUserFullName(), 
+				aslSession.getUserAvatarId());
+
+		return saveNotification(not);
+	}
+	/**
+	 * {@inheritDoc}
+	 * @throws InternalErrorException 
+	 */
+	@Override
+	public boolean notifyRemovedItem(String userIdToNotify, String itemName, WorkspaceFolder sharedFolder) throws InternalErrorException {
+		Notification not = new Notification(
+				UUID.randomUUID().toString(), 
+				NotificationType.WP_ITEM_DELETE, 
+				userIdToNotify, //user no notify
+				sharedFolder.getId(),  //the 
+				new Date(),
+				getApplicationUrl()+"?itemid="+sharedFolder.getId(), 
+				"deleted item "+ itemName +" from your workspace shared folder "+ sharedFolder.getName(),
 				false, 
 				aslSession.getUsername(),
 				aslSession.getUserFullName(), 
@@ -269,7 +290,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				userIdToNotify, //user no notify
 				item.getId(),  //the 
 				new Date(),
-				"?itemid="+item.getParent().getId(), 
+				getApplicationUrl()+"?itemid="+item.getParent().getId(), 
 				" updated "+ item.getName() +" to your workspace shared folder "+ item.getParent().getName(),
 				false, 
 				aslSession.getUsername(),
@@ -290,7 +311,7 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 				userIdToNotify, //user no notify
 				renamedItem.getId(),  //the 
 				new Date(),
-				"?itemid="+renamedItem.getParent().getId(), 
+				getApplicationUrl()+"?itemid="+renamedItem.getParent().getId(), 
 				"renamed " + previousName +" as " + renamedItem.getName() +" in your shared folder " + renamedItem.getParent().getName(),
 				false, 
 				aslSession.getUsername(),
